#[must_use]
pub struct State(_);
Authentication State
State for multi-part (streaming) authenticator tag (HMAC) computation.
When a State goes out of scope its contents will be zeroed out.
NOTE: the streaming interface takes variable length keys, as opposed to the
simple interface which takes a fixed length key. The streaming interface also does not
define its own Key type, instead using slices for its init() method.
The caller of the functions is responsible for zeroing out the key after it's been used
(in contrast to the simple interface which defines a Drop implementation for Key).
NOTE: these functions are specific to libsodium and do not exist in NaCl.
init() initializes an authentication structure using a secret key 'k'.
update() can be called more than once in order to compute the authenticator
from sequential chunks of the message.
finalize() finalizes the authenticator computation and returns a Tag. finalize
consumes the State so that it cannot be accidentally reused.
Executes the destructor for this type. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static